# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.3] - 2026-03-27

### Docs
- Update examples/01-individual-rules/duplicate-imports/README.md
- Update examples/01-individual-rules/missing-return-type/README.md
- Update examples/01-individual-rules/print-statements/README.md
- Update examples/01-individual-rules/relative-imports/README.md
- Update examples/01-individual-rules/sorted-imports/README.md
- Update examples/01-individual-rules/string-concat/README.md
- Update examples/01-individual-rules/wildcard-imports/README.md

### Other
- Update examples/03-output-formats/test-report.json
- Update examples/run_all.sh

## [0.1.2] - 2026-03-27

### Docs
- Update README.md
- Update examples/01-individual-rules/README.md
- Update examples/02-multiple-rules/README.md
- Update examples/03-output-formats/README.md
- Update examples/04-custom-rules/README.md
- Update examples/05-ci-cd/README.md
- Update examples/06-api-usage/README.md
- Update examples/README.md
- Update examples/sample-project/README.md

### Other
- Update examples/01-individual-rules/duplicate-imports/after.py
- Update examples/01-individual-rules/duplicate-imports/before.py
- Update examples/01-individual-rules/duplicate-imports/prefact.yaml
- Update examples/01-individual-rules/missing-return-type/after.py
- Update examples/01-individual-rules/missing-return-type/before.py
- Update examples/01-individual-rules/missing-return-type/prefact.yaml
- Update examples/01-individual-rules/print-statements/after.py
- Update examples/01-individual-rules/print-statements/before.py
- Update examples/01-individual-rules/print-statements/prefact.yaml
- Update examples/01-individual-rules/relative-imports/after.py
- ... and 39 more files

## [0.1.1] - 2026-03-27

### Docs
- Update README.md

### Test
- Update tests/test_config.py
- Update tests/test_engine.py
- Update tests/test_relative_imports.py
- Update tests/test_rules.py
- Update tests/test_unused_imports.py

### Other
- Update PKG-INFO
- Update VERSION
- Update prefact/__init__.py
- Update prefact/cli.py
- Update prefact/core.py
- Update prefact/utils.py

## [0.0.6] - 2026-03-27

### Docs
- Update README.md

### Test
- Update tests/test_refactoring.py

### Other
- Update MANIFEST.in
- Update prefact/__init__.py
- Update prefact/cli.py
- Update prefact/core.py
- Update prefact/utils.py

## [0.0.5] - 2026-03-27

### Other
- Update .idea/inspectionProfiles/Project_Default.xml
- Update .idea/inspectionProfiles/profiles_settings.xml
- Update .idea/misc.xml
- Update .idea/modules.xml
- Update .idea/refactoring.iml
- Update .idea/vcs.xml

## [0.0.4] - 2026-03-27

## [0.0.3] - 2026-03-27

### Other
- Update MANIFEST.in

## [0.0.2] - 2026-03-27

### Test
- Update tests/test_refactoring.py

### Other
- Update refactoring/__init__.py
- Update refactoring/cli.py
- Update refactoring/core.py
- Update refactoring/utils.py

## [0.0.1] - 2026-03-27

### Other
- Update .idea/.gitignore

